# sb::Data::Entry
# == Author(s) : Takuya Otani <takuya.otani@gmail.com> ==
# == Copyright (C) 2004 SimpleBoxes/SerendipityNZ Ltd. ==

# ======================================
package sb::Data::Entry;
use strict;
use sb::Utils ();
use sb::Config ();
use sb::Data::Object ();
use base qw( sb::Data::Object );
use vars qw( $VERSION );
$VERSION = '0.12';
# 0.12 [2008/11/24] modified formatted_body / formatted_more to set 'mode' against sb::Text
# 0.11 [2007/11/30] added 'mod' into table
# 0.10 [2007/11/28] modified to use sb::Utils->remove_duplicates
# 0.09 [2007/08/14] added deprecated functions
# 0.08 [2007/08/11] added 'tag' and 'opt' into table
# 0.07 [2007/08/07] changed default to initialize "cat"
# 0.06 [2007/08/04] added initializer
# 0.05 [2007/07/16] changed return to make them consistent
# 0.04 [2006/07/01] ported from biscuit
# 0.03 [2005/07/25] changed pingurl to use 'basic_tb'
# 0.02 [2005/07/11] changed config variable "srv_cgi" to "conf_srv_cgi"
# 0.01 [2005/07/08] added add_ping as public method
# 0.00 [2005/02/02] generated
# --------------------------------------
# // defines / static variables
sub SUMMARY_LENGTH (){ 200 }
# --------------------------------------
# // override base class
sub table
{
	my $self = shift;
	return (
		'id'   => 'uni_id',   # id
		'wid'  => 'id',       # weblog id (reserved)
		'subj' => 'str(255)', # title [entitized]
		'cat'  => 'id',       # main category
		'date' => 'date',     # date
		'auth' => 'id',       # author id
		'stat' => 'int',      # status
		'com'  => 'int',      # number of comments
		'tb'   => 'int',      # number of trackbacks
		'file' => 'str(255)', # name to save
		'tz'   => 'zone',     # timezone
		'add'  => 'str(255)', # additional categories
		'edit' => 'id',       # editor id
		'acm'  => 'int',      # status for comments
		'atb'  => 'int',      # status for trackbacks
		'form' => 'str(255)', # text format
		'ping' => 'text',     # sent pings
		'body' => 'text',     # body text
		'more' => 'text',     # sequel to the body
		'sum'  => 'text',     # summary of the entry [entitized]
		'key'  => 'text',     # keywords for the entry [entitized]
		'ext'  => 'text',     # extra field (reserved)
		'tmp'  => 'text',     # reserved pings
		'tag'  => 'str(255)', # tag [entitized]
		'opt'  => 'str(255)', # options
		'mod'  => 'date',     # latest modified date
	);
}
# --------------------------------------
# // initializer
BEGIN
{
	__PACKAGE__->init_accessor();
}
sub default
{ # default settings
	my $self  = shift;
	my %param = @_;
	$param{'wid'} |= 0;
	$param{'cat'} = -1 if ($param{'cat'} eq '');
	$param{'auth'} |= 0;
	$param{'edit'} = $param{'auth'} if ($param{'edit'} eq '');
	$param{'com'} |= 0;
	$param{'tb'} |= 0;
	$self->SUPER::initialize(%param);
}
# --------------------------------------
# // public functions
sub add_ping
{
	my $self = shift;
	my @new  = @_;
	my @ping = split("\n",$self->ping);
	push(@ping,@new);
	$self->ping(join("\n",sb::Utils->remove_duplicates(@ping)));
}
sub sum
{
	my $self = shift;
	$self->{'sum'} = shift if @_;
	return $self->{'sum'} if ($self->{'sum'} ne '');
	return sb::Text->new($self->formatted_body)->clip('length'=>SUMMARY_LENGTH);
}
sub formatted_body
{
	my $self = shift;
	return sb::Text->new($self->body)->format($self->form,{'obj'=>$self,'mode'=>'body'});
}
sub formatted_more
{
	my $self = shift;
	return sb::Text->new($self->more)->format($self->form,{'obj'=>$self,'mode'=>'more'});
}
sub file_path
{
	my $self = shift;
	my $cat  = shift;
	my $conf = sb::Config->get;
	my $filename = undef;
	return $filename if ($conf->value('conf_entry_archive') ne 'Individual');
	my $log_dir = $conf->value('conf_dir_log');
	my $logfile = $conf->value('basic_preid') . $self->id;
	$cat = {sb::Data->load_as_hash('Category')} if (! defined($cat));
	if ( defined($cat->{$self->cat}) 
	 and $self->cat ne ''
	 and $cat->{$self->cat}->dir ne '')
	{
		$log_dir = $cat->{$self->cat}->dir;
	}
	$logfile = $self->file if ($self->file ne '');
	$filename = $conf->value('conf_dir_base') . $log_dir . $logfile . $conf->value('basic_suffix');
	return $filename;
}
sub permalink
{
	my $self = shift;
	my %param = (
		'type' => sb::Config->get->value('conf_entry_archive'), # arhive type
		'mode' => '',                                           # output mode
		'cat'  => undef,                                        # sb::Data::Category
		@_
	);
	my $permalink = ''; # output parameter
	my $conf = sb::Config->get; # getting the object of sb::Config
	$param{'type'} = '' if ($param{'type'} eq 'Monthly' and $param{'mode'} ne '');
	TYPE_SWITCH: {
		$_ = $param{'type'};
		/^Individual$/ && do
		{
			$permalink = $self->_filename($param{'cat'},$conf);
			$permalink .= '#comments'  if ($param{'mode'} eq 'com');
			$permalink .= '#trackback' if ($param{'mode'} eq 'tb');
			$permalink .= '#sequel'    if ($param{'mode'} eq 'more');
			last TYPE_SWITCH;
		}; # end of Individual
		/^Monthly$/ && do
		{
			my $filename = sb::Time->format(
				'time' => $self->date,
				'form' => '%Year%%Mon%' . $conf->value('basic_suffix'),
				'zone' => $conf->value('conf_timezone')
			);
			$permalink = $conf->value('conf_srv_base') 
			           . $conf->value('conf_dir_log') 
			           . $filename . '#' . $conf->value('basic_preid') . $self->id;
			last TYPE_SWITCH;
		}; # end of Monthly
		/^Mobile$/ && do
		{
			my $mobile = (index($0,$conf->value('basic_sb')) > -1) 
			           ? $conf->value('basic_sb') 
			           : $conf->value('basic_mob');
			$permalink = $conf->value('conf_srv_cgi') . $mobile . '?eid=' . $self->id;
			$permalink .= '&amp;com=0'  if ($param{'mode'} eq 'com');
			$permalink .= '&amp;tb=0'   if ($param{'mode'} eq 'tb');
			$permalink .= '&amp;more=0' if ($param{'mode'} eq 'more');
			$permalink .= '&amp;form=0' if ($param{'mode'} eq 'form');
			last TYPE_SWITCH;
		}; # end of Mobile
		$permalink = $conf->value('conf_srv_cgi') . $conf->value('basic_sb') . '?eid=' . $self->id;
		$permalink .= '#comments'  if ($param{'mode'} eq 'com');
		$permalink .= '#trackback' if ($param{'mode'} eq 'tb');
		$permalink .= '#sequel'    if ($param{'mode'} eq 'more');
	} # end of TYPE_SWITCH
	return $permalink;
}
sub pingurl
{
	my $self = shift;
	return
		  sb::Config->get->value('conf_srv_cgi') 
		. sb::Config->get->value('basic_tb') 
		. '/' 
		. $self->id;
}
sub authname
{
	my $self = shift;
	my $user = shift;
	$user = {sb::Data->load_as_hash('User')} if (! defined($user));
	my $pid = (defined($user->{$self->auth})) ? $self->auth : 0;
	return $user->{$pid}->real;
}
sub authlink
{
	my $self = shift;
	my $user = shift;
	$user = {sb::Data->load_as_hash('User')} if (! defined($user));
	my $pid = (defined($user->{$self->auth})) ? $self->auth : 0;
	my $cgi = sb::Config->get->value('conf_srv_cgi') . sb::Config->get->value('basic_sb');
	return '<a href="' . $cgi . '?pid=' . $pid . '">' . $self->authname($user) . '</a>';
}
# --------------------------------------
# // public functions - deprecated
sub formated_body
{
	formatted_body(@_);
}
sub formated_more
{
	formatted_more(@_);
}
# --------------------------------------
# // private functions
sub _filename
{
	my $self = shift;
	my ($cat,$conf) = @_;
	my $filename = '';
	my $log_dir = $conf->value('conf_dir_log');
	my $logfile = $conf->value('basic_preid') . $self->id;
	$cat = {sb::Data->load_as_hash('Category')} if (! defined($cat));
	if ( defined($cat->{$self->cat}) 
	 and $self->cat ne ''
	 and $cat->{$self->cat}->dir ne '')
	{
		$log_dir = $cat->{$self->cat}->dir;
	}
	$logfile = $self->file if ($self->file ne '');
	$filename = $conf->value('conf_srv_base') . $log_dir . $logfile . $conf->value('basic_suffix');
	return $filename;
}
1;
__END__
