# sb::Data::Message
# == Author(s) : Takuya Otani <takuya.otani@gmail.com> ==
# == Copyright (C) 2004 SimpleBoxes/SerendipityNZ Ltd. ==

# ======================================
package sb::Data::Message;
use strict;
use sb::Config ();
use sb::Data::Object ();
use base qw( sb::Data::Object );
use vars qw( $VERSION );
$VERSION = '0.06';
# 0.06 [2007/08/14] added deprecated functions
# 0.05 [2007/08/07] changed default to initialize "icon"
# 0.04 [2007/08/04] added initializer
# 0.03 [2007/07/16] changed return to make them consistent
# 0.02 [2007/02/11] ported from biscuit
# 0.01 [2005/07/22] changed data structure to array
# 0.00 [2005/02/02] generated
# --------------------------------------
# // defines / static variables
sub LINK_TARGET (){ ' target="_blank"' }
# --------------------------------------
# // override base class - table
sub table
{
	my $self = shift;
	return (
		'id'   => 'uni_id',   # id
		'wid'  => 'id',       # weblog id (reserved)
		'eid'  => 'id',       # article id
		'stat' => 'int',      # status [-1:closed, 0:waiting, 1:opened, 2:entry isn't opened]
		'date' => 'date',     # received date
		'auth' => 'str(255)', # name
		'host' => 'str(255)', # sender ip address
		'tz'   => 'zone',     # time zone
		'mail' => 'str(255)', # mail address
		'url'  => 'str(255)', # site url
		'agnt' => 'str(255)', # sender user agent
		'body' => 'text',     # comment body
		'icon' => 'id',       # icon
		'ext'  => 'text',     # extra information (reserved)
		'admn' => 'text',     # admin message (reserved)
		'out'  => 'str(255)', # number of outgoing (reserved)
	);
}
# --------------------------------------
# // initializer
BEGIN
{
	__PACKAGE__->init_accessor();
}
sub default
{ # default settings
	my $self  = shift;
	my %param = @_;
	$param{'wid'} |= 0;
	$param{'icon'} = -1 if ($param{'icon'} eq '');
	$self->SUPER::initialize(%param);
}
# --------------------------------------
# // public functions
sub formatted_body
{
	my $self = shift;
	return sb::Text->new($self->body)->format(sb::Config->get->value('basic_com_format'),$self);
}
sub auth_with_url
{
	my $self = shift;
	my $target = LINK_TARGET;
	return ($self->url)
		? '<a href="' . $self->url . '"' . $target . '>' . $self->auth . '</a>'
		: $self->auth;
}
sub get_size
{
	my $self = shift;
	return length($self->formatted_body) + length($self->auth_with_url);
}
sub icon_image
{
	my $self = shift;
	return if ($self->icon eq '');
	my $icon = sb::Data->load('Image','id'=>$self->icon);
	return if (!$icon);
	my $conf = sb::Config->get;
	my $src = $conf->value('conf_srv_base') . $conf->value('conf_dir_img') . $icon->file;
	my $alt = $icon->name;
	my ($w,$h) = $icon->get_size;
	return '<img src="' . $src . '" width="' . $w . '" height="' . $h . 
		     '" alt="' . $alt . '" title="' . $alt . '" class="comment_icon" />';
}
# --------------------------------------
# // public functions - deprecated
sub formated_body
{
	formatted_body(@_);
}
# --------------------------------------
# // private functions
1;
__END__
